==> mono_1.1.8.2.orig.tar.gz: mono-1.1.8.2/mcs/class/corlib/System.Runtime.InteropServices/MarshalAsAttribute.cs <==
//
// System.Runtime.InteropServices.MarshalAsAttribute.cs
//
// Author:
//   Andreas Nahr (ClassDevelopment@A-SoftTech.com)
//

//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;

namespace System.Runtime.InteropServices {

	[AttributeUsage (AttributeTargets.Field | AttributeTargets.Parameter | 
			 AttributeTargets.ReturnValue, Inherited=false)]
	public sealed class MarshalAsAttribute : Attribute {
		private UnmanagedType utype;
		public UnmanagedType ArraySubType;
		public string MarshalCookie;
		public string MarshalType;
		public Type MarshalTypeRef;
		public VarEnum SafeArraySubType;
		public int SizeConst;
		public short SizeParamIndex;
		public Type SafeArrayUserDefinedSubType;
#if NET_2_0
		public int IidParamIndex;
#endif

		public MarshalAsAttribute (short unmanagedType) {
			utype = (UnmanagedType)unmanagedType;
		}
		public MarshalAsAttribute( UnmanagedType unmanagedType) {
			utype = unmanagedType;
		}
		public UnmanagedType Value {
			get {return utype;}
		}
	}
}

==> mono_1.1.13.6.orig.tar.gz: mono-1.1.13.6/mcs/class/corlib/System.Runtime.InteropServices/MarshalAsAttribute.cs <==
//
// System.Runtime.InteropServices.MarshalAsAttribute.cs
//
// Author:
//   Andreas Nahr (ClassDevelopment@A-SoftTech.com)
//

//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;

namespace System.Runtime.InteropServices {

	[AttributeUsage (AttributeTargets.Field | AttributeTargets.Parameter | 
			 AttributeTargets.ReturnValue, Inherited=false)]
	public sealed class MarshalAsAttribute : Attribute {
		private UnmanagedType utype;
		public UnmanagedType ArraySubType;
		public string MarshalCookie;
		public string MarshalType;
		public Type MarshalTypeRef;
		public VarEnum SafeArraySubType;
		public int SizeConst;
		public short SizeParamIndex;
		public Type SafeArrayUserDefinedSubType;
#if NET_2_0
		public int IidParameterIndex;
#endif

		public MarshalAsAttribute (short unmanagedType) {
			utype = (UnmanagedType)unmanagedType;
		}
		public MarshalAsAttribute( UnmanagedType unmanagedType) {
			utype = unmanagedType;
		}
		public UnmanagedType Value {
			get {return utype;}
		}
	}
}
